==> ZenTaoPMS.max2.2.php7.0.zip: zentaopms/module/project/lang/en.php <==
<?php
/* Actions. */
$lang->project->createGuide       = 'Select Template';
$lang->project->index             = 'Dashboard';
$lang->project->home              = 'Home';
$lang->project->create            = 'Create Project';
$lang->project->edit              = 'Edit';
$lang->project->batchEdit         = 'Batch Edit Projects';
$lang->project->view              = 'Project View';
$lang->project->batchEdit         = 'Batch Edit';
$lang->project->browse            = 'Projects';
$lang->project->all               = 'All';
$lang->project->start             = 'Start';
$lang->project->finish            = 'Finish';
$lang->project->suspend           = 'Suspend';
$lang->project->delete            = 'Delete';
$lang->project->close             = 'Close';
$lang->project->activate          = 'Activate';
$lang->project->group             = 'Privilege Group';
$lang->project->createGroup       = 'Create Group';
$lang->project->editGroup         = 'Edit Group';
$lang->project->copyGroup         = 'Copy Group';
$lang->project->manageView        = 'Manage View';
$lang->project->managePriv        = 'Manage Privilege';
$lang->project->manageMembers     = 'Manage Team';
$lang->project->export            = 'Export';
$lang->project->addProduct        = 'Add Product';
$lang->project->manageGroupMember = 'Manage Group';
$lang->project->moduleSetting     = 'List Settings';
$lang->project->moduleOpen        = 'Program Name';
$lang->project->dynamic           = 'Dynamic';
$lang->project->execution         = 'Execution';
$lang->project->qa                = 'QA';
$lang->project->bug               = 'Bug List';
$lang->project->testcase          = 'Case List';
$lang->project->testtask          = 'Test Task';
$lang->project->build             = 'Build';
$lang->project->updateOrder       = 'Order';
$lang->project->sort              = 'Order';
$lang->project->whitelist         = 'Project Whitelist';
$lang->project->addWhitelist      = 'Project Add Whitelist';
$lang->project->unbindWhitelist   = 'Project Remove Whitelist';
$lang->project->manageProducts    = 'Manage Products';
$lang->project->copyTitle         = 'Please select an project to copy';
$lang->project->errorSameProducts = 'Project cannot be associated with multiple identical products.';
$lang->project->errorNoProducts   = 'At least one product is associated';
$lang->project->copyNoProject     = 'There are no items available to copy.';
$lang->project->searchByName      = 'Enter the project name to retrieve';
$lang->project->deleted           = 'Deleted';
$lang->project->linkedProducts    = "Linked {$lang->productCommon}s";
$lang->project->unlinkedProducts  = "Unlinked {$lang->productCommon}s";
$lang->project->testreport        = 'Test Report';
$lang->project->selectProgram     = 'Program filtering';
$lang->project->teamMember        = 'Team Member';
$lang->project->unlinkMember      = 'Remove Member';
$lang->project->copyTeamTitle     = 'Select a project team to copy';

/* Fields. */
$lang->project->common             = 'Project';
$lang->project->id                 = 'ID';
$lang->project->stage              = 'Stage';
$lang->project->model              = 'Model';
$lang->project->PM                 = 'Manager';
$lang->project->PO                 = 'Project Owner';
$lang->project->QD                 = 'Test Leader';
$lang->project->RD                 = 'Releaser';
$lang->project->name               = 'Name';
$lang->project->category           = 'Category';
$lang->project->desc               = 'Description';
$lang->project->code               = 'Code';
$lang->project->copy               = 'Copy';
$lang->project->begin              = 'Begin';
$lang->project->end                = 'End';
$lang->project->status             = 'Status';
$lang->project->subStatus          = 'Sub Status';
$lang->project->type               = 'Type';
$lang->project->pri                = 'Priority';
$lang->project->openedBy           = 'OpenedBy';
$lang->project->openedDate         = 'OpenedDate';
$lang->project->closedBy           = 'ClosedBy';
$lang->project->closedDate         = 'ClosedDate';
$lang->project->canceledBy         = 'CanceledBy';
$lang->project->canceledDate       = 'CanceledDate';
$lang->project->team               = 'Team';
$lang->project->teamAction         = 'Team List';
$lang->project->order              = 'Rank';
$lang->project->budget             = 'Budget';
$lang->project->budgetUnit         = 'Budget Unit';
$lang->project->template           = 'Template';
$lang->project->estimate           = 'Estimates';
$lang->project->consume            = 'Cost';
$lang->project->surplus            = 'Left';
$lang->project->progress           = 'Progress';
$lang->project->dateRange          = 'Duration';
$lang->project->to                 = ' to ';
$lang->project->realEnd            = 'Actual End';
$lang->project->realBegan          = 'Actual Began';
$lang->project->bygrid             = 'Kanban';
$lang->project->bylist             = 'List';
$lang->project->bycard             = 'Card';
$lang->project->mine               = 'My';
$lang->project->myProject          = 'Mine';
$lang->project->other              = 'Others';
$lang->project->acl                = 'Access control';
$lang->project->setPlanduration    = 'Set Duration';
$lang->project->auth               = 'Access Control';
$lang->project->durationEstimation = 'Estimated Workload';
$lang->project->leftStories        = 'Left Stories';
$lang->project->leftTasks          = 'Left Tasks';
$lang->project->leftBugs           = 'Left Bugs';
$lang->project->leftHours          = 'Left Hours';
$lang->project->children           = 'Child Project';
$lang->project->parent             = 'Parent Program';
$lang->project->allStories         = 'All Stories';
$lang->project->doneStories        = 'Finished Stories';
$lang->project->doneProjects       = 'Finished';
$lang->project->allInput           = 'Total Input';
$lang->project->weekly             = 'Program Weekly';
$lang->project->pv                 = 'PV';
$lang->project->ev                 = 'EV';
$lang->project->sv                 = 'SV%';
$lang->project->ac                 = 'AC';
$lang->project->cv                 = 'CV%';
$lang->project->pvTitle            = 'Planed Value';
$lang->project->evTitle            = 'Earn Value';
$lang->project->svTitle            = 'Schedule Variance';
$lang->project->acTitle            = 'Actual Cost';
$lang->project->cvTitle            = 'Cost Variance';
$lang->project->teamCount          = 'Team';
$lang->project->teamSumCount       = '%s people in total';
$lang->project->longTime           = 'Long-Term Program';
$lang->project->future             = 'TBD';
$lang->project->moreProject        = 'More Project';
$lang->project->days               = 'Available Days';
$lang->project->etc                = " , etc";

/* Project Kanban. */
$lang->project->typeList = array();
$lang->project->typeList['my']    = 'Projects Ownedbyme';
$lang->project->typeList['other'] = 'Other Projects';

$lang->project->waitProjects    = 'Waiting Projects';
$lang->project->doingProjects   = 'Ongoing Projects';
$lang->project->doingExecutions = 'Ongoing Executions';
$lang->project->closedProjects  = 'Closed Projects';
$lang->project->noProgram       = 'Independent Projects';

$lang->project->laneColorList = array('#32C5FF', '#006AF1', '#9D28B2', '#FF8F26', '#FFC20E', '#00A78E', '#7FBB00', '#424BAC', '#C0E9FF', '#EC2761');

$lang->project->productNotEmpty        = 'Please link products or create products.';
$lang->project->existProductName       = 'Product name already exists.';
$lang->project->changeProgram          = '%s > Change project';
$lang->project->changeProgramTip       = 'After modifying the project set, the products linked with the project will also modify the project set to which it belongs. Please confirm whether to modify it.';
$lang->project->linkedProjectsTip      = 'Linked projects are as follows';
$lang->project->multiLinkedProductsTip = 'The following products linked to this project are also linked to other projects, please unlink before proceeding.';
$lang->project->linkStoryByPlanTips    = "This action will associate all {$lang->SRCommon} under the selected plan to this project";
$lang->project->createExecution        = "There is no {$lang->executionCommon} under this project, please create {$lang->executionCommon} first";
$lang->project->unlinkExecutionMember  = "The user participated in %s executions such as %s%s. Do you want to remove the user from those executions as well? (The data related to this user will not be deleted.)";
$lang->project->unlinkExecutionMembers = "The team members you are removing are also in the execution team of this project. Do you want to remove them from the execution team too?";

$lang->project->tenThousand = '';

$lang->project->unitList['CNY'] = 'RMB';
$lang->project->unitList['USD'] = 'USD';
$lang->project->unitList['HKD'] = 'HKD';
$lang->project->unitList['NTD'] = 'New Taiwan';
$lang->project->unitList['EUR'] = 'Euro';
$lang->project->unitList['DEM'] = 'Deutsche Mark';
$lang->project->unitList['CHF'] = 'Swiss Franc';
$lang->project->unitList['FRF'] = 'French Franc';
$lang->project->unitList['GBP'] = 'Pound';
$lang->project->unitList['NLG'] = 'Florin';
$lang->project->unitList['CAD'] = 'Canadian';
$lang->project->unitList['RUR'] = 'Russian Ruble';
$lang->project->unitList['INR'] = 'Indian';
$lang->project->unitList['AUD'] = 'Australian';
$lang->project->unitList['NZD'] = 'New Zealand';
$lang->project->unitList['THB'] = 'Thai Baht';
$lang->project->unitList['SGD'] = 'Singapore';

$lang->project->currencySymbol['CNY'] = '¥';
$lang->project->currencySymbol['USD'] = '$';
$lang->project->currencySymbol['HKD'] = 'HK$';
$lang->project->currencySymbol['NTD'] = 'NT$';
$lang->project->currencySymbol['EUR'] = '€';
$lang->project->currencySymbol['DEM'] = 'DEM';
$lang->project->currencySymbol['CHF'] = '₣';
$lang->project->currencySymbol['FRF'] = '₣';
$lang->project->currencySymbol['GBP'] = '£';
$lang->project->currencySymbol['NLG'] = 'ƒ';
$lang->project->currencySymbol['CAD'] = '$';
$lang->project->currencySymbol['RUR'] = '₽';
$lang->project->currencySymbol['INR'] = '₹';
$lang->project->currencySymbol['AUD'] = 'A$';
$lang->project->currencySymbol['NZD'] = 'NZ$';
$lang->project->currencySymbol['THB'] = '฿';
$lang->project->currencySymbol['SGD'] = 'S$';

$lang->project->modelList['scrum']     = "Scrum";
$lang->project->modelList['waterfall'] = "CMMI";

$lang->project->featureBar['all']       = 'All';
$lang->project->featureBar['doing']     = 'Going';
$lang->project->featureBar['wait']      = 'Waiting';
$lang->project->featureBar['suspended'] = 'Suspended';
$lang->project->featureBar['closed']    = 'Closed';

$lang->project->aclList['private'] = 'Private (For the project leader, team members and stakeholders only)';
$lang->project->aclList['open']    = "Open (accessible with project view permissions)";

$lang->project->acls['private'] = 'Private';
$lang->project->acls['open']    = 'Open';

$lang->project->subAclList['private'] = "Private (Only the project leader, team members and stakeholders can access)";
$lang->project->subAclList['open']    = "Open (accessible with project view permissions)";
$lang->project->subAclList['program'] = 'Open in the program (all upper-level program team leaders and stakeholders, the project leader, team members and stakeholders can access)';

$lang->project->authList['extend'] = 'Inherit (system privilege and project privilege)';
$lang->project->authList['reset']  = 'Reset (project privilege only)';

$lang->project->statusList['wait']      = 'Waiting';
$lang->project->statusList['doing']     = 'Doing';
$lang->project->statusList['suspended'] = 'Suspended';
$lang->project->statusList['closed']    = 'Closed';
$lang->project->statusList['delay']     = 'Delayed';

$lang->project->endList[31]  = 'One month';
$lang->project->endList[93]  = 'Trimester';
$lang->project->endList[186] = 'Half yearly';
$lang->project->endList[365] = 'One year';
$lang->project->endList[999] = 'Longtime';

$lang->project->empty                  = 'No project.';
$lang->project->nextStep               = 'Next step';
$lang->project->hoursUnit              = '%s hours';
$lang->project->membersUnit            = '%s men';
$lang->project->lastIteration          = "Recent {$lang->executionCommon}";
$lang->project->ongoingStage           = 'Ongoing stage';
$lang->project->scrum                  = 'Scrum';
$lang->project->waterfall              = 'CMMI';
$lang->project->waterfallTitle         = 'CMMI';
$lang->project->cannotCreateChild      = 'It is not empty, so you cannot add a child. You can add a parent for it, and then create a child.';
$lang->project->confirmDelete          = "Do you want to delete [%s]?";
$lang->project->emptyPM                = 'No manager';
$lang->project->cannotChangeToCat      = "It is not empty, so you cannot change it to a parent.";
$lang->project->cannotCancelCat        = "It has child projects, so you cannot unmark the parent.";
$lang->project->parentBeginEnd         = "Parent begin&end date: %s ~ %s";
$lang->project->childLongTime          = "If a child as long-term projects, the parent should be long-term too.";
$lang->project->readjustTime           = 'Change the project begin&end date.';
$lang->project->notAllowRemoveProducts = 'The story of this product is linked with the project. Unlink it before doing any action.';

$lang->project->programTitle['0']    = 'Hidden';
$lang->project->programTitle['base'] = 'Base-level project only';
$lang->project->programTitle['end']  = 'End-level project only';

$lang->project->accessDenied        = 'Access denied to this project';
$lang->project->chooseProgramType   = 'Select management type';
$lang->project->scrumTitle          = 'Agile Development Management';
$lang->project->cannotCreateChild   = 'The project has contents, so you cannot add a child project. You can create a parent project for this one and then add a child project for the parent project.';
$lang->project->hasChildren         = 'This project has a child project, so it cannot be deleted.';
$lang->project->confirmDelete       = 'Do you want to delete this project?';
$lang->project->cannotChangeToCat   = "The project has contents, so you cannot it to a parent project.";
$lang->project->cannotCancelCat     = "There are child projects of this project. You cannot cancel the parent project mark.";
$lang->project->parentBeginEnd      = "The begin and end date of the parent project: %s ~ %s";
$lang->project->parentBudget        = "The budget of the parent project: ";
$lang->project->beginLetterParent   = "The begin date of the parent project: %s. It cannot be < the begin date of its parent project.";
$lang->project->endGreaterParent    = "The end date of the parent project: %s. It cannot be > the end date of its parent project.";
$lang->project->beginGreateChild    = "The minimum start date of the project set: %s. The start date of the project cannot be less than the minimum start date of the project set.";
$lang->project->endLetterChild      = "The maximum finish date for the project set: %s. The completion date of a project cannot be greater than the maximum completion date of the project set.";
$lang->project->childLongTime       = "There are long-term projects in the child project, and the parent project should also be a long-term project.";
$lang->project->confirmUnlinkMember = "Do you want to remove this user from project?";

==> ZenTaoPMS.max2.7.php7.0.zip: zentaopms/module/project/lang/en.php <==
<?php
/* Actions. */
$lang->project->createGuide       = 'Select Template';
$lang->project->index             = 'Dashboard';
$lang->project->home              = 'Home';
$lang->project->create            = 'Create Project';
$lang->project->edit              = 'Edit';
$lang->project->batchEdit         = 'Batch Edit Projects';
$lang->project->view              = 'Project View';
$lang->project->batchEdit         = 'Batch Edit';
$lang->project->browse            = 'Projects';
$lang->project->all               = 'All';
$lang->project->start             = 'Start';
$lang->project->finish            = 'Finish';
$lang->project->suspend           = 'Suspend';
$lang->project->delete            = 'Delete';
$lang->project->close             = 'Close';
$lang->project->activate          = 'Activate';
$lang->project->group             = 'Privilege Group';
$lang->project->createGroup       = 'Create Group';
$lang->project->editGroup         = 'Edit Group';
$lang->project->copyGroup         = 'Copy Group';
$lang->project->manageView        = 'Manage View';
$lang->project->managePriv        = 'Manage Privilege';
$lang->project->manageMembers     = 'Manage Team';
$lang->project->export            = 'Export';
$lang->project->addProduct        = 'Add Product';
$lang->project->manageGroupMember = 'Manage Group';
$lang->project->moduleSetting     = 'List Settings';
$lang->project->moduleOpen        = 'Program Name';
$lang->project->dynamic           = 'Dynamic';
$lang->project->execution         = 'Execution';
$lang->project->qa                = 'QA';
$lang->project->bug               = 'Bug List';
$lang->project->testcase          = 'Case List';
$lang->project->testtask          = 'Test Task';
$lang->project->build             = 'Build';
$lang->project->updateOrder       = 'Order';
$lang->project->sort              = 'Order';
$lang->project->whitelist         = 'Project Whitelist';
$lang->project->addWhitelist      = 'Project Add Whitelist';
$lang->project->unbindWhitelist   = 'Project Remove Whitelist';
$lang->project->manageProducts    = 'Manage Products';
$lang->project->copyTitle         = 'Please select an project to copy';
$lang->project->errorSameProducts = 'Project cannot be associated with multiple identical products.';
$lang->project->errorSameBranches = 'Project cannot be associated with multiple identical branches.';
$lang->project->errorNoProducts   = 'At least one product is associated';
$lang->project->copyNoProject     = 'There are no items available to copy.';
$lang->project->searchByName      = 'Enter the project name to retrieve';
$lang->project->deleted           = 'Deleted';
$lang->project->linkedProducts    = "Linked {$lang->productCommon}s";
$lang->project->unlinkedProducts  = "Unlinked {$lang->productCommon}s";
$lang->project->testreport        = 'Test Report';
$lang->project->selectProgram     = 'Program filtering';
$lang->project->teamMember        = 'Team Member';
$lang->project->unlinkMember      = 'Remove Member';
$lang->project->copyTeamTitle     = 'Select a project team to copy';

/* Fields. */
$lang->project->common             = 'Project';
$lang->project->id                 = 'ID';
$lang->project->project            = 'Project';
$lang->project->stage              = 'Stage';
$lang->project->model              = 'Model';
$lang->project->PM                 = 'Manager';
$lang->project->PO                 = 'Project Owner';
$lang->project->QD                 = 'Test Leader';
$lang->project->RD                 = 'Releaser';
$lang->project->name               = 'Name';
$lang->project->category           = 'Category';
$lang->project->desc               = 'Description';
$lang->project->code               = 'Code';
$lang->project->copy               = 'Copy';
$lang->project->begin              = 'Planned Begin';
$lang->project->end                = 'Planned End';
$lang->project->status             = 'Status';
$lang->project->subStatus          = 'Sub Status';
$lang->project->type               = 'Type';
$lang->project->lifetime           = 'Project Cycle';
$lang->project->attribute          = 'Stage Type';
$lang->project->percent            = 'Workload %';
$lang->project->milestone          = 'Milestone';
$lang->project->output             = 'Output';
$lang->project->path               = 'Path';
$lang->project->grade              = 'Grade';
$lang->project->version            = 'Version';
$lang->project->parentVersion      = 'Parent Version';
$lang->project->planDuration       = 'Plan Duration';
$lang->project->realDuration       = 'Real Duration';
$lang->project->openedVersion      = 'Opened Version';
$lang->project->pri                = 'Priority';
$lang->project->openedBy           = 'OpenedBy';
$lang->project->openedDate         = 'OpenedDate';
$lang->project->lastEditedBy       = 'Last EditedBy';
$lang->project->lastEditedDate     = 'Last EditedDate';
$lang->project->closedBy           = 'ClosedBy';
$lang->project->closedDate         = 'ClosedDate';
$lang->project->canceledBy         = 'CanceledBy';
$lang->project->canceledDate       = 'CanceledDate';
$lang->project->team               = 'Team';
$lang->project->teamAction         = 'Team List';
$lang->project->order              = 'Rank';
$lang->project->budget             = 'Budget';
$lang->project->budgetUnit         = 'Budget Unit';
$lang->project->template           = 'Template';
$lang->project->estimate           = 'Estimates';
$lang->project->consume            = 'Cost';
$lang->project->surplus            = 'Left';
$lang->project->progress           = 'Progress';
$lang->project->dateRange          = 'Duration';
$lang->project->to                 = ' to ';
$lang->project->realBeganAB        = 'Actual Begin';
$lang->project->realEndAB          = 'Actual End';
$lang->project->realBegan          = 'Actual Begin';
$lang->project->realEnd            = 'Actual End';
$lang->project->bygrid             = 'Kanban';
$lang->project->bylist             = 'List';
$lang->project->bycard             = 'Card';
$lang->project->mine               = 'My';
$lang->project->myProject          = 'Mine';
$lang->project->other              = 'Others';
$lang->project->acl                = 'ACL';
$lang->project->setPlanduration    = 'Set Duration';
$lang->project->auth               = 'Privileges';
$lang->project->durationEstimation = 'Estimated Workload';
$lang->project->leftStories        = 'Left Stories';
$lang->project->leftTasks          = 'Left Tasks';
$lang->project->leftBugs           = 'Left Bugs';
$lang->project->leftHours          = 'Left Hours';
$lang->project->children           = 'Child Project';
$lang->project->parent             = 'Parent Program';
$lang->project->allStories         = 'All Stories';
$lang->project->doneStories        = 'Finished Stories';
$lang->project->doneProjects       = 'Finished';
$lang->project->allInput           = 'Total Input';
$lang->project->weekly             = 'Program Weekly';
$lang->project->pv                 = 'PV';
$lang->project->ev                 = 'EV';
$lang->project->sv                 = 'SV%';
$lang->project->ac                 = 'AC';
$lang->project->cv                 = 'CV%';
$lang->project->pvTitle            = 'Planed Value';
$lang->project->evTitle            = 'Earn Value';
$lang->project->svTitle            = 'Schedule Variance';
$lang->project->acTitle            = 'Actual Cost';
$lang->project->cvTitle            = 'Cost Variance';
$lang->project->teamCount          = 'Team';
$lang->project->teamSumCount       = '%s people in total';
$lang->project->longTime           = 'Long-Term Program';
$lang->project->future             = 'TBD';
$lang->project->moreProject        = 'More Project';
$lang->project->days               = 'Days';
$lang->project->mailto             = 'Mailto';
$lang->project->etc                = " , etc";
$lang->project->product            = 'Product';
$lang->project->branch             = 'Branch';
$lang->project->plan               = 'Plan';
$lang->project->createKanban       = 'Create Kanban';
$lang->project->kanban             = 'Kanban';

/* Project Kanban. */
$lang->project->typeList = array();
$lang->project->typeList['my']    = 'Projects Ownedbyme';
$lang->project->typeList['other'] = 'Other Projects';

$lang->project->waitProjects    = 'Waiting Projects';
$lang->project->doingProjects   = 'Ongoing Projects';
$lang->project->doingExecutions = 'Ongoing Executions';
$lang->project->closedProjects  = 'Closed Projects(The recent two projects)';
$lang->project->noProgram       = 'Independent Projects';

$lang->project->laneColorList = array('#32C5FF', '#006AF1', '#9D28B2', '#FF8F26', '#FFC20E', '#00A78E', '#7FBB00', '#424BAC', '#C0E9FF', '#EC2761');

$lang->project->productNotEmpty        = 'Please link products or create products.';
$lang->project->existProductName       = 'Product name already exists.';
$lang->project->changeProgram          = '%s > Change project';
$lang->project->changeProgramTip       = 'Once the program is edited, the product that is linked to this program will be changed. Do you want to edit it?';
$lang->project->linkedProjectsTip      = 'Linked projects are as follows';
$lang->project->multiLinkedProductsTip = 'The following products linked to this project are also linked to other projects, please unlink before proceeding.';
$lang->project->linkStoryByPlanTips    = "This action will associate all {$lang->SRCommon} under the selected plan to this project";
$lang->project->createExecution        = "There is no {$lang->executionCommon} under this project, please create {$lang->executionCommon} first";
$lang->project->unlinkExecutionMember  = "The user participated in %s executions such as %s%s. Do you want to remove the user from those executions as well? (The data related to this user will not be deleted.)";
$lang->project->unlinkExecutionMembers = "The team members you are removing are also in the execution team of this project. Do you want to remove them from the execution team too?";

$lang->project->tenThousand = '';

$lang->project->unitList['CNY'] = 'RMB';
$lang->project->unitList['USD'] = 'USD';
$lang->project->unitList['HKD'] = 'HKD';
$lang->project->unitList['NTD'] = 'NTD';
$lang->project->unitList['EUR'] = 'EUR';
$lang->project->unitList['DEM'] = 'DEM';
$lang->project->unitList['CHF'] = 'CHF';
$lang->project->unitList['FRF'] = 'FRF';
$lang->project->unitList['GBP'] = 'GPR';
$lang->project->unitList['NLG'] = 'NLG';
$lang->project->unitList['CAD'] = 'CAD';
$lang->project->unitList['RUR'] = 'RUB';
$lang->project->unitList['INR'] = 'IDR';
$lang->project->unitList['AUD'] = 'AUD';
$lang->project->unitList['NZD'] = 'NZD';
$lang->project->unitList['THB'] = 'THB';
$lang->project->unitList['SGD'] = 'SGD';

$lang->project->currencySymbol['CNY'] = '¥';
$lang->project->currencySymbol['USD'] = '$';
$lang->project->currencySymbol['HKD'] = 'HK$';
$lang->project->currencySymbol['NTD'] = 'NT$';
$lang->project->currencySymbol['EUR'] = '€';
$lang->project->currencySymbol['DEM'] = 'DEM';
$lang->project->currencySymbol['CHF'] = '₣';
$lang->project->currencySymbol['FRF'] = '₣';
$lang->project->currencySymbol['GBP'] = '£';
$lang->project->currencySymbol['NLG'] = 'ƒ';
$lang->project->currencySymbol['CAD'] = '$';
$lang->project->currencySymbol['RUR'] = '₽';
$lang->project->currencySymbol['INR'] = '₹';
$lang->project->currencySymbol['AUD'] = 'A$';
$lang->project->currencySymbol['NZD'] = 'NZ$';
$lang->project->currencySymbol['THB'] = '฿';
$lang->project->currencySymbol['SGD'] = 'S$';

$lang->project->modelList['scrum']     = "Scrum";
$lang->project->modelList['waterfall'] = "CMMI";
$lang->project->modelList['kanban']    = "Kanban";

$lang->project->featureBar['all']       = 'All';
$lang->project->featureBar['doing']     = 'Going';
$lang->project->featureBar['wait']      = 'Waiting';
$lang->project->featureBar['suspended'] = 'Suspended';
$lang->project->featureBar['closed']    = 'Closed';

$lang->project->aclList['private'] = 'Private (For the project leader, team members and stakeholders only)';
$lang->project->aclList['open']    = "Open (accessible with project view permissions)";

$lang->project->acls['private'] = 'Private';
$lang->project->acls['open']    = 'Open';

$lang->project->subAclList['private'] = "Private (Only the project leader, team members and stakeholders can access)";
$lang->project->subAclList['open']    = "Open (accessible with project view permissions)";
$lang->project->subAclList['program'] = 'Open in the program (all upper-level program team leaders and stakeholders, the project leader, team members and stakeholders can access)';

$lang->project->authList['extend'] = 'Inherit (system privilege and project privilege)';
$lang->project->authList['reset']  = 'Reset (project privilege only)';

$lang->project->statusList['wait']      = 'Waiting';
$lang->project->statusList['doing']     = 'Doing';
$lang->project->statusList['suspended'] = 'Suspended';
$lang->project->statusList['closed']    = 'Closed';
$lang->project->statusList['delay']     = 'Delayed';

$lang->project->endList[31]  = 'One month';
$lang->project->endList[93]  = 'Trimester';
$lang->project->endList[186] = 'Half yearly';
$lang->project->endList[365] = 'One year';
$lang->project->endList[999] = 'Longtime';

$lang->project->scrumTitle     = 'Agile Development Management';
$lang->project->waterfallTitle = 'Waterfall Project Management';
$lang->project->kanbanTitle    = 'Kanban Project Management';

$lang->project->empty                  = 'No project.';
$lang->project->nextStep               = 'Next step';
$lang->project->hoursUnit              = '%s hours';
$lang->project->membersUnit            = '%s men';
$lang->project->lastIteration          = "Recent {$lang->executionCommon}";
$lang->project->ongoingStage           = 'Ongoing stage';
$lang->project->scrum                  = 'Scrum';
$lang->project->waterfall              = 'Waterfall';
$lang->project->cannotCreateChild      = 'It is not empty, so you cannot add a child. You can add a parent for it, and then create a child.';
$lang->project->confirmDelete          = "Do you want to delete [%s]?";
$lang->project->emptyPM                = 'No manager';
$lang->project->cannotChangeToCat      = "It is not empty, so you cannot change it to a parent.";
$lang->project->cannotCancelCat        = "It has child projects, so you cannot unmark the parent.";
$lang->project->parentBeginEnd         = "Parent begin&end date: %s ~ %s";
$lang->project->childLongTime          = "If a child as long-term projects, the parent should be long-term too.";
$lang->project->readjustTime           = 'Change the project begin&end date.';
$lang->project->notAllowRemoveProducts = "Stories of this product are linked to projects or {$lang->execution->common} of this project is linked to this product. Please unlink it and try again.";
$lang->project->ge                     = "『%s』should be >= actual begin『%s』.";

$lang->project->programTitle['0']    = 'Hidden';
$lang->project->programTitle['base'] = 'Base-level project only';
$lang->project->programTitle['end']  = 'End-level project only';

$lang->project->accessDenied        = 'Access denied to this project';
$lang->project->chooseProgramType   = 'Select management type';
$lang->project->cannotCreateChild   = 'The project has contents, so you cannot add a child project. You can create a parent project for this one and then add a child project for the parent project.';
$lang->project->hasChildren         = 'This project has a child project, so it cannot be deleted.';
$lang->project->confirmDelete       = 'Do you want to delete this project?';
$lang->project->cannotChangeToCat   = "The project has contents, so you cannot it to a parent project.";
$lang->project->cannotCancelCat     = "There are child projects of this project. You cannot cancel the parent project mark.";
$lang->project->parentBeginEnd      = "The begin and end date of the parent project: %s ~ %s";
$lang->project->parentBudget        = "The budget of the parent project: ";
$lang->project->beginLetterParent   = "The begin date of the parent project: %s. It cannot be < the begin date of its parent project.";
$lang->project->endGreaterParent    = "The end date of the parent project: %s. It cannot be > the end date of its parent project.";
$lang->project->beginGreateChild    = "The minimum start date of the project set: %s. The start date of the project cannot be less than the minimum start date of the project set.";
$lang->project->endLetterChild      = "The maximum finish date for the project set: %s. The completion date of a project cannot be greater than the maximum completion date of the project set.";
$lang->project->childLongTime       = "There are long-term projects in the child project, and the parent project should also be a long-term project.";
$lang->project->confirmUnlinkMember = "Do you want to remove this user from project?";

$lang->project->action = new stdclass();
$lang->project->action->managed = '$date, managed by <strong>$actor</strong>. $extra' . "\n";
